@@ -19,19 +19,19 @@
     switch(method, total = {
         if (missing(MARGIN))
             MARGIN <- 1
-        tmp <- pmax(k, apply(x, MARGIN, sum, na.rm = na.rm))
+        tmp <- pmax.int(k, apply(x, MARGIN, sum, na.rm = na.rm))
         x <- sweep(x, MARGIN, tmp, "/")
         attr <- list("total" = tmp, "margin" = MARGIN)
     }, max = {
         if (missing(MARGIN))
             MARGIN <- 2
-        tmp <- pmax(k, apply(x, MARGIN, max, na.rm = na.rm))
+        tmp <- pmax.int(k, apply(x, MARGIN, max, na.rm = na.rm))
         x <- sweep(x, MARGIN, tmp, "/")
         attr <- list("max" = tmp, "margin" = MARGIN)
     }, frequency = {
         if (missing(MARGIN))
             MARGIN <- 2
-        tmp <- pmax(k, apply(x, MARGIN, sum, na.rm = na.rm))
+        tmp <- pmax.int(k, apply(x, MARGIN, sum, na.rm = na.rm))
         fre <- apply(x > 0, MARGIN, sum, na.rm = na.rm)
         tmp <- fre/tmp
         x <- sweep(x, MARGIN, tmp, "*")
@@ -40,7 +40,7 @@
         if (missing(MARGIN))
             MARGIN <- 1
         tmp <- apply(x^2, MARGIN, sum, na.rm = na.rm)
-        tmp <- pmax(.Machine$double.eps, sqrt(tmp))
+        tmp <- pmax.int(.Machine$double.eps, sqrt(tmp))
         x <- sweep(x, MARGIN, tmp, "/")
         attr <- list("norm" = tmp, "margin" = MARGIN)
     }, range = {
@@ -56,7 +56,7 @@
         tmp <- apply(xtmp, MARGIN, min, na.rm = na.rm)
         ran <- apply(xtmp, MARGIN, max, na.rm = na.rm)
         ran <- ran - tmp
-        ran <- pmax(k, ran, na.rm = na.rm)
+        ran <- pmax.int(k, ran, na.rm = na.rm)
         x <- sweep(x, MARGIN, tmp, "-")
         x <- sweep(x, MARGIN, ran, "/")
         attr <- list("min" = tmp, "range" = ran, "margin" = MARGIN)
@@ -91,8 +91,8 @@
         ## MARGIN 2 transposes the result!
         if (MARGIN == 2)
             x <- t(x)
-        rs <- pmax(k, rowSums(x, na.rm = na.rm))
-        cs <- pmax(k, colSums(x, na.rm = na.rm))
+        rs <- pmax.int(k, rowSums(x, na.rm = na.rm))
+        cs <- pmax.int(k, colSums(x, na.rm = na.rm))
         tot <- sum(x, na.rm = na.rm)
         x <- sqrt(tot) * x/outer(rs, sqrt(cs))
         attr <- list("tot" = tot, "rsum" = rs, "csum" = cs, margin = MARGIN)
@@ -156,6 +156,7 @@
         stop("'clr' cannot be used with non-positive data: use pseudocount > ",
              -min(x, na.rm = na.rm) + pseudocount, call. = FALSE)
     }
+
     # In every sample, calculate the log of individual entries.
     # Then calculate
     # the sample-specific mean value and subtract every entries'
